/*===========================================================================

OpenCCM: The Open CORBA Component Model Platform
Copyright (C) 2000-2004 INRIA - USTL - LIFL - GOAL
Contact: openccm@objectweb.org

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
USA

Initial developer(s): Jrme Moroy.
Contributor(s):  ______________________________________.

===========================================================================*/

package org.objectweb.ccm.chat.explorer;

/** The administration console's API imports */
import org.objectweb.util.explorer.api.MenuItem;
import org.objectweb.util.explorer.api.MenuItemTreeView;
import org.objectweb.util.explorer.api.TreeView;
import org.objectweb.util.explorer.swing.gui.api.DialogAction;
import org.objectweb.util.explorer.swing.gui.api.DialogBox;
import org.objectweb.util.explorer.swing.gui.lib.DefaultDialogBox;
import org.objectweb.util.explorer.swing.gui.lib.LabelBox;
import org.objectweb.util.explorer.api.Tree;

import org.objectweb.ccm.chat.Client;

/**
 * This action allows us to rename a client.
 *
 * @author <a href="mailto:Jerome.Moroy@lifl.fr">Jerome Moroy</a>
 * 
 * @version 0.1
 */
public class ChangeNameAttribute 
  implements MenuItem, DialogAction
{

    //==================================================================
    //
    // Internal states.
    //
    //==================================================================

    /** The associated Client */
    protected Client client_ = null;

    /** The name of the client */
    protected LabelBox nameLabel_ = null;

    //==================================================================
    //
    // No constructor.
    //
    //==================================================================

    //==================================================================
    //
    // No internal method.
    //
    //==================================================================
 
    //==================================================================
    //
    // Public methods for MenuItem interface.
    //
    //==================================================================

    /**
     * Always enabled.
     */
    public int getStatus(TreeView treeView) {
        return MenuItem.ENABLED_STATUS;
    }

    /**
     * Provides a dialog box in order to inform about the name.
     */
    public void actionPerformed(MenuItemTreeView e) {
        client_ = (Client) e.getParentObject();
        DialogBox dialog = new DefaultDialogBox("Change the name attribute");      
        nameLabel_ = new LabelBox("name",client_.name());
        dialog.addElementBox(nameLabel_);
        dialog.setValidateAction(this);
        dialog.show();
    }

    //==================================================================
    //
    // Public methods for DialogAction interface.
    //
    //==================================================================

    /**
     * Fixes the name.
     */
    public void executeAction() throws Exception {
        client_.name(nameLabel_.getLabel());
    }    

}
